All Classes and Interfaces

Class
Description
Deprecated, for removal: This API element is subject to removal in a future version.
since 7.0 in favor of AbstractWebServiceInboundGateway
 
Deprecated, for removal: This API element is subject to removal in a future version.
since 7.0 in favor of AbstractWebServiceOutboundGateway
Base class for outbound Web Service-invoking Messaging Gateways.
Base MessagingGatewaySpec for web services.
The base MessageHandlerSpec for AbstractWebServiceOutboundGateways.
A HeaderMapper implementation for mapping to and from a SoapHeader.
 
Deprecated, for removal: This API element is subject to removal in a future version.
Deprecated, for removal: This API element is subject to removal in a future version.
An outbound Messaging Gateway for invoking Web Services that also supports marshalling and unmarshalling of the request and response messages.
Spec for a MarshallingWebServiceOutboundGateway where an external WebServiceTemplate is not provided.
The WebServiceException extension to indicate that the server endpoint is temporary unavailable.
 
Deprecated, for removal: This API element is subject to removal in a future version.
since 7.0 in favor of SimpleWebServiceInboundGateway
An outbound Messaging Gateway for invoking a Web Service.
Deprecated, for removal: This API element is subject to removal in a future version.
since 7.0 in favor of SimpleWebServiceOutboundGateway
Spec for a SimpleWebServiceOutboundGateway where an external WebServiceTemplate is not provided.
A convenience interface that extends RequestReplyHeaderMapper, parameterized with SoapHeader.
 
Pre-defined header names to be used when storing or retrieving Web Service properties to/from integration Message Headers.
 
Parser for the <outbound-gateway/> element in the 'ws' namespace.
Factory class for web service components.
The IntegrationConfigurationInitializer implementation for the WebService module.