Class MarshallingWebServiceOutboundGateway

java.lang.Object
org.springframework.integration.context.IntegrationObjectSupport
org.springframework.integration.handler.MessageHandlerSupport
org.springframework.integration.handler.AbstractMessageHandler
org.springframework.integration.handler.AbstractMessageProducingHandler
org.springframework.integration.handler.AbstractReplyProducingMessageHandler
All Implemented Interfaces:
org.reactivestreams.Subscriber<org.springframework.messaging.Message<?>>, org.springframework.beans.factory.Aware, org.springframework.beans.factory.BeanClassLoaderAware, org.springframework.beans.factory.BeanFactoryAware, org.springframework.beans.factory.BeanNameAware, org.springframework.beans.factory.DisposableBean, org.springframework.beans.factory.InitializingBean, org.springframework.context.ApplicationContextAware, org.springframework.core.Ordered, org.springframework.integration.context.ComponentSourceAware, org.springframework.integration.context.ExpressionCapable, org.springframework.integration.context.Orderable, org.springframework.integration.core.MessageProducer, org.springframework.integration.handler.HeaderPropagationAware, org.springframework.integration.IntegrationPattern, org.springframework.integration.support.context.NamedComponent, org.springframework.integration.support.management.IntegrationManagement, org.springframework.integration.support.management.TrackableComponent, org.springframework.messaging.MessageHandler, reactor.core.CoreSubscriber<org.springframework.messaging.Message<?>>

@Deprecated(forRemoval=true, since="7.0") public class MarshallingWebServiceOutboundGateway extends MarshallingWebServiceOutboundGateway
Deprecated, for removal: This API element is subject to removal in a future version.
An outbound Messaging Gateway for invoking Web Services that also supports marshalling and unmarshalling of the request and response messages.
See Also:
  • Marshaller
  • Unmarshaller
  • Nested Class Summary

    Nested classes/interfaces inherited from class org.springframework.integration.handler.AbstractReplyProducingMessageHandler

    org.springframework.integration.handler.AbstractReplyProducingMessageHandler.RequestHandler

    Nested classes/interfaces inherited from interface org.springframework.integration.support.management.IntegrationManagement

    org.springframework.integration.support.management.IntegrationManagement.ManagementOverrides
  • Field Summary

    Fields inherited from class AbstractWebServiceOutboundGateway

    uriFactory

    Fields inherited from class org.springframework.integration.handler.AbstractMessageProducingHandler

    messagingTemplate

    Fields inherited from class org.springframework.integration.context.IntegrationObjectSupport

    EXPRESSION_PARSER, logger

    Fields inherited from interface org.springframework.integration.support.management.IntegrationManagement

    METER_PREFIX, RECEIVE_COUNTER_NAME, SEND_TIMER_NAME

    Fields inherited from interface org.springframework.core.Ordered

    HIGHEST_PRECEDENCE, LOWEST_PRECEDENCE
  • Constructor Summary

    Constructors
    Constructor
    Description
    MarshallingWebServiceOutboundGateway(@Nullable String uri, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.oxm.Unmarshaller unmarshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(@Nullable String uri, org.springframework.ws.client.core.WebServiceTemplate webServiceTemplate)
    Deprecated, for removal: This API element is subject to removal in a future version.
    Construct an instance based on the provided Web Service URI and WebServiceTemplate.
    MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller, org.springframework.oxm.Unmarshaller unmarshaller)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.oxm.Unmarshaller unmarshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, org.springframework.oxm.Unmarshaller unmarshaller)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
    Deprecated, for removal: This API element is subject to removal in a future version.
     
    MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.ws.client.core.WebServiceTemplate webServiceTemplate)
    Deprecated, for removal: This API element is subject to removal in a future version.
    Construct an instance based on the provided DestinationProvider and WebServiceTemplate.
  • Method Summary

    Methods inherited from class org.springframework.integration.handler.AbstractReplyProducingMessageHandler

    doInvokeAdvisedRequestHandler, getBeanClassLoader, getIntegrationPatternType, getRequiresReply, handleMessageInternal, hasAdviceChain, onInit, setAdviceChain, setBeanClassLoader, setRequiresReply

    Methods inherited from class org.springframework.integration.handler.AbstractMessageProducingHandler

    addNotPropagatedHeaders, createOutputMessage, getNotPropagatedHeaders, getOutputChannel, isAsync, messageBuilderForReply, produceOutput, resolveErrorChannel, sendErrorMessage, sendOutput, sendOutputs, setAsync, setNotPropagatedHeaders, setOutputChannel, setOutputChannelName, setSendTimeout, setupMessageProcessor, shouldCopyRequestHeaders, shouldSplitOutput, updateNotPropagatedHeaders

    Methods inherited from class org.springframework.integration.handler.AbstractMessageHandler

    handleMessage, onComplete, onError, onNext, onSubscribe, setObservationConvention

    Methods inherited from class org.springframework.integration.handler.MessageHandlerSupport

    buildSendTimer, destroy, getManagedName, getManagedType, getMetricsCaptor, getObservationRegistry, getOrder, getOverrides, isLoggingEnabled, isObserved, registerMetricsCaptor, registerObservationRegistry, sendTimer, setLoggingEnabled, setManagedName, setManagedType, setOrder, setShouldTrack, shouldTrack

    Methods inherited from class org.springframework.integration.context.IntegrationObjectSupport

    afterPropertiesSet, extractTypeIfPossible, generateId, getApplicationContext, getApplicationContextId, getBeanDescription, getBeanFactory, getBeanName, getChannelResolver, getComponentDescription, getComponentName, getComponentSource, getConversionService, getExpression, getIntegrationProperties, getMessageBuilderFactory, getTaskScheduler, isInitialized, setApplicationContext, setBeanFactory, setBeanName, setChannelResolver, setComponentDescription, setComponentName, setComponentSource, setConversionService, setMessageBuilderFactory, setPrimaryExpression, setTaskScheduler, toString

    Methods inherited from class Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait

    Methods inherited from interface reactor.core.CoreSubscriber

    currentContext

    Methods inherited from interface org.springframework.integration.support.management.IntegrationManagement

    getThisAs

    Methods inherited from interface org.springframework.integration.support.context.NamedComponent

    getBeanName, getComponentName
  • Constructor Details

    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.oxm.Unmarshaller unmarshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, org.springframework.oxm.Unmarshaller unmarshaller)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.oxm.Marshaller marshaller)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(@Nullable String uri, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.oxm.Unmarshaller unmarshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller, org.springframework.oxm.Unmarshaller unmarshaller)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(String uri, org.springframework.oxm.Marshaller marshaller)
      Deprecated, for removal: This API element is subject to removal in a future version.
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(@Nullable String uri, org.springframework.ws.client.core.WebServiceTemplate webServiceTemplate)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Construct an instance based on the provided Web Service URI and WebServiceTemplate.
      Parameters:
      uri - the Web Service URI to use
      webServiceTemplate - the WebServiceTemplate
      Since:
      5.0
    • MarshallingWebServiceOutboundGateway

      public MarshallingWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, org.springframework.ws.client.core.WebServiceTemplate webServiceTemplate)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Construct an instance based on the provided DestinationProvider and WebServiceTemplate.
      Parameters:
      destinationProvider - the DestinationProvider to resolve Web Service URI at runtime
      webServiceTemplate - the WebServiceTemplate
      Since:
      5.0