Class AbstractWebServiceOutboundGateway
java.lang.Object
org.springframework.integration.context.IntegrationObjectSupport
org.springframework.integration.handler.MessageHandlerSupport
org.springframework.integration.handler.AbstractMessageHandler
org.springframework.integration.handler.AbstractMessageProducingHandler
org.springframework.integration.handler.AbstractReplyProducingMessageHandler
org.springframework.integration.ws.outbound.AbstractWebServiceOutboundGateway
org.springframework.integration.ws.AbstractWebServiceOutboundGateway
- All Implemented Interfaces:
org.reactivestreams.Subscriber<org.springframework.messaging.Message<?>>, org.springframework.beans.factory.Aware, org.springframework.beans.factory.BeanClassLoaderAware, org.springframework.beans.factory.BeanFactoryAware, org.springframework.beans.factory.BeanNameAware, org.springframework.beans.factory.DisposableBean, org.springframework.beans.factory.InitializingBean, org.springframework.context.ApplicationContextAware, org.springframework.core.Ordered, org.springframework.integration.context.ComponentSourceAware, org.springframework.integration.context.ExpressionCapable, org.springframework.integration.context.Orderable, org.springframework.integration.core.MessageProducer, org.springframework.integration.handler.HeaderPropagationAware, org.springframework.integration.IntegrationPattern, org.springframework.integration.support.context.NamedComponent, org.springframework.integration.support.management.IntegrationManagement, org.springframework.integration.support.management.TrackableComponent, org.springframework.messaging.MessageHandler, reactor.core.CoreSubscriber<org.springframework.messaging.Message<?>>
@Deprecated(forRemoval=true,
since="7.0")
public abstract class AbstractWebServiceOutboundGateway
extends AbstractWebServiceOutboundGateway
Deprecated, for removal: This API element is subject to removal in a future version.
Base class for outbound Web Service-invoking Messaging Gateways.
-
Nested Class Summary
Nested classes/interfaces inherited from class AbstractWebServiceOutboundGateway
AbstractWebServiceOutboundGateway.RequestMessageCallback, AbstractWebServiceOutboundGateway.ResponseMessageExtractorNested classes/interfaces inherited from class org.springframework.integration.handler.AbstractReplyProducingMessageHandler
org.springframework.integration.handler.AbstractReplyProducingMessageHandler.RequestHandlerNested classes/interfaces inherited from interface org.springframework.integration.support.management.IntegrationManagement
org.springframework.integration.support.management.IntegrationManagement.ManagementOverrides -
Field Summary
Fields inherited from class AbstractWebServiceOutboundGateway
uriFactoryFields inherited from class org.springframework.integration.handler.AbstractMessageProducingHandler
messagingTemplateFields inherited from class org.springframework.integration.context.IntegrationObjectSupport
EXPRESSION_PARSER, loggerFields inherited from interface org.springframework.integration.support.management.IntegrationManagement
METER_PREFIX, RECEIVE_COUNTER_NAME, SEND_TIMER_NAMEFields inherited from interface org.springframework.core.Ordered
HIGHEST_PRECEDENCE, LOWEST_PRECEDENCE -
Constructor Summary
ConstructorsConstructorDescriptionAbstractWebServiceOutboundGateway(@Nullable String uri, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory) Deprecated, for removal: This API element is subject to removal in a future version.AbstractWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory) Deprecated, for removal: This API element is subject to removal in a future version. -
Method Summary
Methods inherited from class AbstractWebServiceOutboundGateway
doHandle, doInit, doSetWebServiceTemplate, getWebServiceTemplate, handleRequestMessage, setEncodingMode, setFaultMessageResolver, setHeaderMapper, setIgnoreEmptyResponses, setInterceptors, setMessageFactory, setMessageSenders, setReplyChannel, setRequestCallback, setUriVariableExpressions, setWebServiceTemplateMethods inherited from class org.springframework.integration.handler.AbstractReplyProducingMessageHandler
doInvokeAdvisedRequestHandler, getBeanClassLoader, getIntegrationPatternType, getRequiresReply, handleMessageInternal, hasAdviceChain, onInit, setAdviceChain, setBeanClassLoader, setRequiresReplyMethods inherited from class org.springframework.integration.handler.AbstractMessageProducingHandler
addNotPropagatedHeaders, createOutputMessage, getNotPropagatedHeaders, getOutputChannel, isAsync, messageBuilderForReply, produceOutput, resolveErrorChannel, sendErrorMessage, sendOutput, sendOutputs, setAsync, setNotPropagatedHeaders, setOutputChannel, setOutputChannelName, setSendTimeout, setupMessageProcessor, shouldCopyRequestHeaders, shouldSplitOutput, updateNotPropagatedHeadersMethods inherited from class org.springframework.integration.handler.AbstractMessageHandler
handleMessage, onComplete, onError, onNext, onSubscribe, setObservationConventionMethods inherited from class org.springframework.integration.handler.MessageHandlerSupport
buildSendTimer, destroy, getComponentType, getManagedName, getManagedType, getMetricsCaptor, getObservationRegistry, getOrder, getOverrides, isLoggingEnabled, isObserved, registerMetricsCaptor, registerObservationRegistry, sendTimer, setLoggingEnabled, setManagedName, setManagedType, setOrder, setShouldTrack, shouldTrackMethods inherited from class org.springframework.integration.context.IntegrationObjectSupport
afterPropertiesSet, extractTypeIfPossible, generateId, getApplicationContext, getApplicationContextId, getBeanDescription, getBeanFactory, getBeanName, getChannelResolver, getComponentDescription, getComponentName, getComponentSource, getConversionService, getExpression, getIntegrationProperties, getMessageBuilderFactory, getTaskScheduler, isInitialized, setApplicationContext, setBeanFactory, setBeanName, setChannelResolver, setComponentDescription, setComponentName, setComponentSource, setConversionService, setMessageBuilderFactory, setPrimaryExpression, setTaskScheduler, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface reactor.core.CoreSubscriber
currentContextMethods inherited from interface org.springframework.integration.support.management.IntegrationManagement
getThisAsMethods inherited from interface org.springframework.integration.support.context.NamedComponent
getBeanName, getComponentName
-
Constructor Details
-
AbstractWebServiceOutboundGateway
public AbstractWebServiceOutboundGateway(@Nullable String uri, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory) Deprecated, for removal: This API element is subject to removal in a future version. -
AbstractWebServiceOutboundGateway
public AbstractWebServiceOutboundGateway(org.springframework.ws.client.support.destination.DestinationProvider destinationProvider, @Nullable org.springframework.ws.WebServiceMessageFactory messageFactory) Deprecated, for removal: This API element is subject to removal in a future version.
-
AbstractWebServiceOutboundGateway